pub struct Create {
pub controller: Pubkey,
pub controller_admin: Pubkey,
pub fee_payer: Pubkey,
pub pc_mint: Pubkey,
pub pc_vault: Pubkey,
pub clock: Pubkey,
pub token_program: Pubkey,
pub associated_token_program: Pubkey,
pub system_program: Pubkey,
pub rent: Pubkey,
}Expand description
Generated client accounts for Create.
Fields
controller: Pubkeycontroller_admin: Pubkeyfee_payer: Pubkeypc_mint: Pubkeypc_vault: Pubkeyclock: Pubkeytoken_program: Pubkeyassociated_token_program: Pubkeysystem_program: Pubkeyrent: PubkeyTrait Implementations
Sourceimpl BorshSerialize for Createwhere
Pubkey: BorshSerialize,
impl BorshSerialize for Createwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for Create
impl ToAccountMetas for Create
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for Create
impl RefUnwindSafe for Create
impl Send for Create
impl Sync for Create
impl Unpin for Create
impl UnwindSafe for Create