pub struct CreateAgent {
pub controller: Pubkey,
pub agent: Pubkey,
pub agent_authorizer: Pubkey,
pub rent_payer: Pubkey,
pub proxy: Pubkey,
pub agent_vault: Pubkey,
pub system_program: Pubkey,
pub associated_token_program: Pubkey,
pub rent: Pubkey,
}Expand description
Generated client accounts for CreateAgent.
Fields
controller: Pubkeyagent: Pubkeyrent_payer: Pubkeyproxy: Pubkeyagent_vault: Pubkeysystem_program: Pubkeyassociated_token_program: Pubkeyrent: PubkeyTrait Implementations
Sourceimpl BorshSerialize for CreateAgentwhere
Pubkey: BorshSerialize,
impl BorshSerialize for CreateAgentwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for CreateAgent
impl ToAccountMetas for CreateAgent
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for CreateAgent
impl RefUnwindSafe for CreateAgent
impl Send for CreateAgent
impl Sync for CreateAgent
impl Unpin for CreateAgent
impl UnwindSafe for CreateAgent