pub struct CreateAgentWithAssociatedTokenAccount {
pub controller: Pubkey,
pub agent: Pubkey,
pub agent_authorizer: Pubkey,
pub system_program: Pubkey,
pub token_program: Pubkey,
pub associated_token_program: Pubkey,
pub rent: Pubkey,
pub agent_vault: Pubkey,
pub pc_mint: Pubkey,
pub agent_vault_owner: Pubkey,
}Expand description
Generated client accounts for CreateAgentWithAssociatedTokenAccount.
Fields
controller: Pubkeyagent: Pubkeysystem_program: Pubkeytoken_program: Pubkeyassociated_token_program: Pubkeyrent: Pubkeyagent_vault: Pubkeypc_mint: Pubkeyagent_vault_owner: PubkeyTrait Implementations
Sourceimpl ToAccountMetas for CreateAgentWithAssociatedTokenAccount
impl ToAccountMetas for CreateAgentWithAssociatedTokenAccount
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for CreateAgentWithAssociatedTokenAccount
impl RefUnwindSafe for CreateAgentWithAssociatedTokenAccount
impl Send for CreateAgentWithAssociatedTokenAccount
impl Sync for CreateAgentWithAssociatedTokenAccount
impl Unpin for CreateAgentWithAssociatedTokenAccount
impl UnwindSafe for CreateAgentWithAssociatedTokenAccount