pub struct IssueAgent {
pub controller: Pubkey,
pub agent: Pubkey,
}Expand description
Generated client accounts for IssueAgent.
Fields
controller: Pubkeyagent: PubkeyTrait Implementations
Sourceimpl BorshSerialize for IssueAgentwhere
Pubkey: BorshSerialize,
impl BorshSerialize for IssueAgentwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for IssueAgent
impl ToAccountMetas for IssueAgent
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for IssueAgent
impl RefUnwindSafe for IssueAgent
impl Send for IssueAgent
impl Sync for IssueAgent
impl Unpin for IssueAgent
impl UnwindSafe for IssueAgent