pub struct ProtocolCreate {
pub protocol: Pubkey,
pub fee_payer: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for ProtocolCreate.
Fields
protocol: Pubkeyfee_payer: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ProtocolCreatewhere
Pubkey: BorshSerialize,
impl BorshSerialize for ProtocolCreatewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for ProtocolCreate
impl ToAccountMetas for ProtocolCreate
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ProtocolCreate
impl RefUnwindSafe for ProtocolCreate
impl Send for ProtocolCreate
impl Sync for ProtocolCreate
impl Unpin for ProtocolCreate
impl UnwindSafe for ProtocolCreate