pub struct ProtocolUpdate {
pub protocol: Pubkey,
pub protocol_admin: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for ProtocolUpdate.
Fields
protocol: Pubkeyprotocol_admin: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ProtocolUpdatewhere
Pubkey: BorshSerialize,
impl BorshSerialize for ProtocolUpdatewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for ProtocolUpdate
impl ToAccountMetas for ProtocolUpdate
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ProtocolUpdate
impl RefUnwindSafe for ProtocolUpdate
impl Send for ProtocolUpdate
impl Sync for ProtocolUpdate
impl Unpin for ProtocolUpdate
impl UnwindSafe for ProtocolUpdate