pub struct Create {
pub _controller_fee_num: u64,
pub _controller_fee_den: u64,
pub _api_hash: [u8; 32],
}Expand description
Instruction.
Fields
_controller_fee_num: u64_controller_fee_den: u64_api_hash: [u8; 32]Trait Implementations
Sourceimpl BorshDeserialize for Create
impl BorshDeserialize for Create
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Create
impl BorshSerialize for Create
Sourceimpl Discriminator for Create
impl Discriminator for Create
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for Create
impl InstructionData for Create