pub struct ProtocolCreate {
pub _fee_num: u64,
pub _fee_den: u64,
}Expand description
Instruction.
Fields
_fee_num: u64_fee_den: u64Trait Implementations
Sourceimpl BorshDeserialize for ProtocolCreatewhere
u64: BorshDeserialize,
impl BorshDeserialize for ProtocolCreatewhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ProtocolCreatewhere
u64: BorshSerialize,
impl BorshSerialize for ProtocolCreatewhere
u64: BorshSerialize,
Sourceimpl Discriminator for ProtocolCreate
impl Discriminator for ProtocolCreate
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for ProtocolCreate
impl InstructionData for ProtocolCreate