pub struct Agent {
pub bump: u8,
pub controller: Pubkey,
pub authorizer: Pubkey,
pub index: u64,
pub extra1: u64,
pub extra2: u64,
pub extra3: u64,
pub vault: Pubkey,
}Expand description
Account: Agent
Fields
bump: u8controller: Pubkeyindex: u64extra1: u64extra2: u64extra3: u64vault: PubkeyTrait Implementations
Sourceimpl AccountDeserialize for Agent
impl AccountDeserialize for Agent
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for Agent
impl AccountSerialize for Agent
Sourceimpl BorshDeserialize for Agent
impl BorshDeserialize for Agent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Agent
impl BorshSerialize for Agent
Sourceimpl Discriminator for Agent
impl Discriminator for Agent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for Agent