pub struct Controller {
pub controller_bump: u8,
pub admin: Pubkey,
pub crank_authority: Pubkey,
pub api_hash: [u8; 32],
pub controller_fee: [u64; 2],
pub pc_vault: Pubkey,
pub pc_mint: Pubkey,
pub index: u64,
}Expand description
Account: Controller
Fields
controller_bump: u8admin: Pubkeyapi_hash: [u8; 32]controller_fee: [u64; 2]pc_vault: Pubkeypc_mint: Pubkeyindex: u64Trait Implementations
Sourceimpl AccountDeserialize for Controller
impl AccountDeserialize for Controller
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for Controller
impl AccountSerialize for Controller
Sourceimpl BorshDeserialize for Controllerwhere
u8: BorshDeserialize,
Pubkey: BorshDeserialize,
[u8; 32]: BorshDeserialize,
[u64; 2]: BorshDeserialize,
u64: BorshDeserialize,
impl BorshDeserialize for Controllerwhere
u8: BorshDeserialize,
Pubkey: BorshDeserialize,
[u8; 32]: BorshDeserialize,
[u64; 2]: BorshDeserialize,
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Controllerwhere
u8: BorshSerialize,
Pubkey: BorshSerialize,
[u8; 32]: BorshSerialize,
[u64; 2]: BorshSerialize,
u64: BorshSerialize,
impl BorshSerialize for Controllerwhere
u8: BorshSerialize,
Pubkey: BorshSerialize,
[u8; 32]: BorshSerialize,
[u64; 2]: BorshSerialize,
u64: BorshSerialize,
Sourceimpl Clone for Controller
impl Clone for Controller
Sourcefn clone(&self) -> Controller
fn clone(&self) -> Controller
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for Controller
impl Default for Controller
Sourcefn default() -> Controller
fn default() -> Controller
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for Controller
impl Discriminator for Controller
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for Controller